@@ -51,23 +51,24 @@ package com.openexchange.drive.events.apn.internal;
 
 import java.util.ArrayList;
 import java.util.List;
-import javapns.Push;
-import javapns.communication.exceptions.CommunicationException;
-import javapns.communication.exceptions.KeystoreException;
-import javapns.devices.Device;
-import javapns.devices.exceptions.InvalidDeviceTokenFormatException;
-import javapns.json.JSONException;
-import javapns.json.JSONObject;
-import javapns.notification.PayloadPerDevice;
-import javapns.notification.PushNotificationPayload;
-import javapns.notification.PushedNotification;
-import javapns.notification.PushedNotifications;
+import org.json.JSONException;
+import org.json.JSONObject;
 import com.openexchange.drive.events.DriveEvent;
 import com.openexchange.drive.events.DriveEventPublisher;
 import com.openexchange.drive.events.apn.APNAccess;
 import com.openexchange.drive.events.subscribe.DriveSubscriptionStore;
 import com.openexchange.drive.events.subscribe.Subscription;
 import com.openexchange.exception.OXException;
+import javapns.Push;
+import javapns.communication.exceptions.CommunicationException;
+import javapns.communication.exceptions.KeystoreException;
+import javapns.devices.Device;
+import javapns.devices.exceptions.InvalidDeviceTokenFormatException;
+import javapns.notification.PayloadPerDevice;
+import javapns.notification.PushNotificationBigPayload;
+import javapns.notification.PushNotificationPayload;
+import javapns.notification.PushedNotification;
+import javapns.notification.PushedNotifications;
 
 /**
  * {@link APNDriveEventPublisher}
@@ -103,7 +104,7 @@ public abstract class APNDriveEventPublisher implements DriveEventPublisher {
             LOG.error("unable to get subscriptions for service {}", getServiceID(), e);
         }
         if (null != subscriptions && 0 < subscriptions.size()) {
-            List<PayloadPerDevice> payloads = getPayloads(event, subscriptions);
+            List<PayloadPerDevice> payloads = getSilentNotificationPayloads(subscriptions);
             if (0 < payloads.size()) {
                 PushedNotifications notifications = null;
                 try {
@@ -197,8 +198,9 @@ public abstract class APNDriveEventPublisher implements DriveEventPublisher {
         List<PayloadPerDevice> payloads = new ArrayList<PayloadPerDevice>(subscriptions.size());
         for (Subscription subscription : subscriptions) {
             try {
-                PushNotificationPayload payload = new PushNotificationPayload();
+                PushNotificationPayload payload = new PushNotificationBigPayload();
                 payload.addCustomDictionary("root", subscription.getRootFolderID());
+                payload.addCustomDictionary("action", "sync");
                 JSONObject apsObject = payload.getPayload().getJSONObject("aps");
                 if (null == apsObject) {
                     apsObject = new JSONObject();
@@ -225,7 +227,7 @@ public abstract class APNDriveEventPublisher implements DriveEventPublisher {
                 continue;
             }
             try {
-                PushNotificationPayload payload = new PushNotificationPayload();
+                PushNotificationPayload payload = new PushNotificationBigPayload();
                 payload.addCustomAlertLocKey("TRIGGER_SYNC");
                 payload.addCustomAlertActionLocKey("OK");
                 payload.addCustomDictionary("root", subscription.getRootFolderID());
