@@ -49,6 +49,10 @@
 
 package com.openexchange.drive.json.action;
 
+import java.util.ArrayList;
+import java.util.List;
+import org.json.JSONArray;
+import org.json.JSONException;
 import org.json.JSONObject;
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
@@ -86,10 +90,32 @@ public class UnsubscribeAction extends AbstractDriveAction {
             throw AjaxExceptionCodes.MISSING_PARAMETER.create("service");
         }
         /*
-         * add subscription
+         * get optional root folder identifiers
+         */
+        List<String> rootFolderIDs = null;
+        Object data = requestData.getData();
+        if (null != data) {
+            if (false == JSONObject.class.isInstance(data)) {
+                throw AjaxExceptionCodes.MISSING_REQUEST_BODY.create();
+            }
+            JSONObject dataObject = (JSONObject) data;
+            JSONArray rootArray = dataObject.optJSONArray("root");
+            if (null != rootArray && 0 < rootArray.length()) {
+                rootFolderIDs = new ArrayList<String>(rootArray.length());
+                try {
+                    for (int i = 0; i < rootArray.length(); i++) {
+                        rootFolderIDs.add(rootArray.getString(i));
+                    }
+                } catch (JSONException e) {
+                    throw AjaxExceptionCodes.JSON_ERROR.create(e, e.getMessage());
+                }
+            }
+        }
+        /*
+         * remove subscription(s)
          */
         DriveSubscriptionStore subscriptionStore = Services.getService(DriveSubscriptionStore.class, true);
-        subscriptionStore.unsubscribe(session.getServerSession(), serviceID, token);
+        subscriptionStore.unsubscribe(session.getServerSession(), serviceID, token, rootFolderIDs);
         /*
          * return empty json object to indicate success
          */
