@@ -50,6 +50,7 @@
 package com.openexchange.drive.json.internal;
 
 import java.util.HashSet;
+import java.util.List;
 import java.util.Set;
 import java.util.SortedSet;
 import java.util.TreeSet;
@@ -113,7 +114,10 @@ public class ListenerRegistrar implements DriveEventPublisher  {
                      * remove from root folder <=> listener id mapping, too
                      */
                     LongPollingListener listener = notification.getValue();
-                    listenersPerFolder.remove(getFolderKey(listener.getSession()), notification.getKey());
+                    int contextID = listener.getSession().getServerSession().getContextId();
+                    for (String rootFolderID : listener.getRootFolderIDs()) {
+                        listenersPerFolder.remove(getFolderKey(rootFolderID, contextID), notification.getKey());
+                    }
                     LOG.debug("Unregistered listener: {}", listener);
                 }
             })
@@ -125,19 +129,24 @@ public class ListenerRegistrar implements DriveEventPublisher  {
      * Gets the long polling listener for the supplied session, creating one if not yet present.
      *
      * @param session The session
+     * @param rootFolderIDs The root folder IDs to listen for changes in
      * @return The listener
      */
-    public LongPollingListener getOrCreate(final DriveSession session) throws ExecutionException {
-        final String listenerID = getListenerID(session);
+    public LongPollingListener getOrCreate(final DriveSession session, final List<String> rootFolderIDs) throws ExecutionException {
+        final String listenerID = getListenerID(session, rootFolderIDs);
+        final int contextID = session.getServerSession().getContextId();
         return listeners.get(listenerID, new Callable<LongPollingListener>() {
 
             @Override
             public LongPollingListener call() throws Exception {
-                LongPollingListener listener = createListener(session);
-                listenersPerFolder.put(getFolderKey(session), listenerID);
-                if (LOG.isDebugEnabled()) {
-                    LOG.debug("Registered new listener: {}", listener);
+                /*
+                 * create listener & track monitored root folders
+                 */
+                LongPollingListener listener = createListener(session, rootFolderIDs);
+                for (String rootFolderID : rootFolderIDs) {
+                    listenersPerFolder.put(getFolderKey(rootFolderID, contextID), listenerID);
                 }
+                LOG.debug("Registered new listener: {}", listener);
                 return listener;
             }
         });
@@ -185,11 +194,11 @@ public class ListenerRegistrar implements DriveEventPublisher  {
         }
     }
 
-    private LongPollingListener createListener(DriveSession session) throws OXException {
+    private LongPollingListener createListener(DriveSession session, List<String> rootFolderIDs) throws OXException {
         if (false == listenerFactories.isEmpty()) {
             LongPollingListenerFactory listenerFactory = listenerFactories.first();
             if (null != listenerFactory) {
-                return listenerFactory.create(session);
+                return listenerFactory.create(session, rootFolderIDs);
             }
         }
         throw DriveExceptionCodes.LONG_POLLING_NOT_AVAILABLE.create(
@@ -200,12 +209,13 @@ public class ListenerRegistrar implements DriveEventPublisher  {
         return String.valueOf(contextID) + ':' + folderID;
     }
 
-    private static String getFolderKey(DriveSession session) {
-        return getFolderKey(session.getRootFolderID(), session.getServerSession().getContextId());
-    }
-
-    private static String getListenerID(DriveSession session) {
-        return getFolderKey(session) + ':' + session.getServerSession().getSessionID();
+    private static String getListenerID(DriveSession session, List<String> rootFolderIDs) {
+        StringBuilder stringBuilder = new StringBuilder()
+            .append(session.getServerSession().getContextId()).append(':').append(session.getServerSession().getSessionID());
+        for (String rootFolderID : rootFolderIDs) {
+            stringBuilder.append(':').append(rootFolderID);
+        }
+        return stringBuilder.toString();
     }
 
 }
